sub config_file { UI::config_file() }
sub ecmd_dir { UI::ecmd_dir() }
sub this_wav_dir { UI::this_wav_dir() }
sub project_dir { UI::project_dir() }
sub prepare { UI::prepare() }
sub wav_dir { UI::wav_dir() }
sub eval_iam { UI::eval_iam() }
sub global_config { UI::global_config() }
sub project_config { UI::project_config() }
sub config { UI::config() }
sub read_config { UI::read_config() }
sub walk_tree { UI::walk_tree() }
sub substitute { UI::substitute() }
sub load_project { UI::load_project() }
sub project_init { UI::project_init() }
sub initialize_project_data { UI::initialize_project_data() }
sub add_track { UI::add_track() }
sub add_mix_track { UI::add_mix_track() }
sub mix_suffix { UI::mix_suffix() }
sub restore_track { UI::restore_track() }
sub register_track { UI::register_track() }
sub dig_ruins { UI::dig_ruins() }
sub find_wavs { UI::find_wavs() }
sub remove_small_wavs { UI::remove_small_wavs() }
sub new_take { UI::new_take() }
sub increment_take { UI::increment_take() }
sub decrement_take { UI::decrement_take() }
sub select_take { UI::select_take() }
sub add_volume_control { UI::add_volume_control() }
sub add_pan_control { UI::add_pan_control() }
sub selected_version { UI::selected_version() }
sub set_active_version { UI::set_active_version() }
sub new_version { UI::new_version() }
sub get_versions { UI::get_versions() }
sub mon_vert { UI::mon_vert() }
sub collect_chains { UI::collect_chains() }
sub rec_status { UI::rec_status() }
sub really_recording { UI::really_recording() }
sub make_io_lists { UI::make_io_lists() }
sub rec_route { UI::rec_route() }
sub route { UI::route() }
sub hash_push { UI::hash_push() }
sub eliminate_loops { UI::eliminate_loops() }
sub write_chains { UI::write_chains() }
sub new_wav_name { UI::new_wav_name() }
sub output_format { UI::output_format() }
sub initialize_oids { UI::initialize_oids() }
sub mono_to_stereo { UI::mono_to_stereo() }
sub pre_multi { UI::pre_multi() }
sub convert_to_jack { UI::convert_to_jack() }
sub convert_to_alsa { UI::convert_to_alsa() }
sub load_ecs { UI::load_ecs() }
sub new_engine { UI::new_engine() }
sub setup_transport { UI::setup_transport() }
sub connect_transport { UI::connect_transport() }
sub start_transport { UI::start_transport() }
sub stop_transport { UI::stop_transport() }
sub transport_running { UI::transport_running() }
sub disconnect_transport { UI::disconnect_transport() }
sub start_clock { UI::start_clock() }
sub update_clock { UI::update_clock() }
sub restart_clock { UI::restart_clock() }
sub refresh_clock { UI::refresh_clock() }
sub toggle_unit { UI::toggle_unit() }
sub to_start { UI::to_start() }
sub to_end { UI::to_end() }
sub jump { UI::jump() }
sub refresh_t { UI::refresh_t() }
sub refresh_c { UI::refresh_c() }
sub refresh { UI::refresh() }
sub rec_cleanup { UI::rec_cleanup() }
sub update_version_button { UI::update_version_button() }
sub update_master_version_button { UI::update_master_version_button() }
sub add_effect { UI::add_effect() }
sub remove_effect { UI::remove_effect() }
sub remove_op { UI::remove_op() }
sub cop_add { UI::cop_add() }
sub cop_init { UI::cop_init() }
sub effect_update { UI::effect_update() }
sub find_op_offsets { UI::find_op_offsets() }
sub apply_ops { UI::apply_ops() }
sub apply_op { UI::apply_op() }
sub prepare_static_effects_data { UI::prepare_static_effects_data() }
sub extract_effects_data { UI::extract_effects_data() }
sub sort_ladspa_effects { UI::sort_ladspa_effects() }
sub read_in_effects_data { UI::read_in_effects_data() }
sub read_in_tkeca_effects_data { UI::read_in_tkeca_effects_data() }
sub get_ladspa_hints { UI::get_ladspa_hints() }
sub range { UI::range() }
sub integrate_ladspa_hints { UI::integrate_ladspa_hints() }
sub d2 { UI::d2() }
sub dn { UI::dn() }
sub round { UI::round() }
sub save_state { UI::save_state() }
sub retrieve_state { UI::retrieve_state() }
sub save_effects { UI::save_effects() }
sub r { UI::r() }
sub r5 { UI::r5() }
sub retrieve_effects { UI::retrieve_effects() }
sub arm_mark { UI::arm_mark() }
sub colonize { UI::colonize() }
sub mark { UI::mark() }
